@@ -1,22 +1,19 @@
 from math import floor
-from six.moves import xrange
-from six import integer_types
 
 from tilecloud import TileCoord, TileGrid
 
 
 class FreeTileGrid(TileGrid):
-
     def __init__(self, resolutions, max_extent=None, tile_size=None, scale=1, flip_y=False):
         TileGrid.__init__(self, max_extent=max_extent, tile_size=tile_size, flip_y=flip_y)
         assert list(resolutions) == sorted(resolutions, reverse=True)
-        assert all(isinstance(r, integer_types) for r in resolutions)
+        assert all(isinstance(r, (int, float)) for r in resolutions)
         self.resolutions = resolutions
-        self.scale = 1 if scale is 1 else float(scale)
+        self.scale = float(scale)
         self.parent_zs = []
         self.child_zs = []
         for i, resolution in enumerate(self.resolutions):
-            for parent in xrange(i - 1, -1, -1):
+            for parent in range(i - 1, -1, -1):
                 if self.resolutions[parent] % resolution == 0:
                     self.parent_zs.append(parent)
                     self.child_zs[parent].append(i)
@@ -29,23 +26,37 @@ class FreeTileGrid(TileGrid):
         if tilecoord.z < len(self.resolutions):
             for child_z in self.child_zs[tilecoord.z]:
                 factor = self.resolutions[tilecoord.z] / self.resolutions[child_z]
-                for i in xrange(0, int(factor)):
+                for i in range(0, int(factor)):
                     x = factor * tilecoord.x + i
-                    for j in xrange(0, int(factor)):
+                    for j in range(0, int(factor)):
                         y = factor * tilecoord.y + j
                         yield TileCoord(child_z, x, y)
 
     def extent(self, tilecoord, border=0):
         y = tilecoord.y
         if not self.flip_y:
-            n = self.scale * (self.max_extent[3] - self.max_extent[1]) / \
-                float(self.tile_size * self.resolutions[tilecoord.z])
+            n = (
+                self.scale
+                * (self.max_extent[3] - self.max_extent[1])
+                / float(self.tile_size * self.resolutions[tilecoord.z])
+            )
             y = n - y - tilecoord.n
-        minx = self.max_extent[0] + (self.tile_size * tilecoord.x - border) * self.resolutions[tilecoord.z] / self.scale
+        minx = (
+            self.max_extent[0]
+            + (self.tile_size * tilecoord.x - border) * self.resolutions[tilecoord.z] / self.scale
+        )
         miny = self.max_extent[1] + (self.tile_size * y - border) * self.resolutions[tilecoord.z] / self.scale
-        maxx = self.max_extent[0] + (self.tile_size * (tilecoord.x + tilecoord.n) + border) * self.resolutions[tilecoord.z] / self.scale
-        maxy = self.max_extent[1] + (self.tile_size * (y + tilecoord.n) + border) * self.resolutions[tilecoord.z] / self.scale
-        return (minx, miny, maxx, maxy)
+        maxx = (
+            self.max_extent[0]
+            + (self.tile_size * (tilecoord.x + tilecoord.n) + border)
+            * self.resolutions[tilecoord.z]
+            / self.scale
+        )
+        maxy = (
+            self.max_extent[1]
+            + (self.tile_size * (y + tilecoord.n) + border) * self.resolutions[tilecoord.z] / self.scale
+        )
+        return minx, miny, maxx, maxy
 
     def parent(self, tilecoord):
         parent_z = self.parent_zs[tilecoord.z]
@@ -73,11 +84,14 @@ class FreeTileGrid(TileGrid):
         ty = self.scale * (y - self.max_extent[1]) / float(self.resolutions[z] * self.tile_size)
 
         if not self.flip_y:
-            n = self.scale * (self.max_extent[3] - self.max_extent[1]) / \
-                float(self.tile_size * self.resolutions[z])
+            n = (
+                self.scale
+                * (self.max_extent[3] - self.max_extent[1])
+                / float(self.tile_size * self.resolutions[z])
+            )
             ty = n - ty
 
         return TileCoord(z, int(floor(tx)), int(floor(ty)))
 
     def zs(self):
-        return xrange(len(self.resolutions))
+        return range(len(self.resolutions))
