@@ -1,10 +1,7 @@
-from six import iterkeys
-
 from tilecloud import Tile, TileStore
 
 
 class DictTileStore(TileStore):
-
     def __init__(self, tiles=None, **kwargs):
         self.tiles = tiles or {}
         TileStore.__init__(self, **kwargs)
@@ -27,7 +24,7 @@ class DictTileStore(TileStore):
             return None
 
     def list(self):
-        for tilecoord in iterkeys(self.tiles):
+        for tilecoord in self.tiles.keys():
             yield Tile(tilecoord)
 
     def put_one(self, tile):
